==> myfaces-tobago-1.5.13-source-release.zip: tobago-1.5.13/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/ImageTagDeclaration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.component;

import org.apache.myfaces.tobago.apt.annotation.BodyContent;
import org.apache.myfaces.tobago.apt.annotation.Tag;
import org.apache.myfaces.tobago.apt.annotation.TagAttribute;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;
import org.apache.myfaces.tobago.component.RendererTypes;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasBorder;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasCurrentMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasIdBindingAndRendered;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasTip;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsDisabled;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsGridLayoutComponentWithDimension;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsGridLayoutContainer;

/**
 * Renders an image.
 */
@Tag(name = "image", bodyContent = BodyContent.JSP)
@UIComponentTag(
    uiComponent = "org.apache.myfaces.tobago.component.UIImage",
    uiComponentBaseClass = "org.apache.myfaces.tobago.internal.component.AbstractUIImage",
    rendererType = RendererTypes.IMAGE,
    allowedChildComponenents = "NONE")
public interface ImageTagDeclaration
    extends HasIdBindingAndRendered, HasBorder, HasTip, IsDisabled, HasMarkup, HasCurrentMarkup,
    IsGridLayoutComponentWithDimension, IsGridLayoutContainer {

  /**
   * Absolute url to an image or image name to lookup in tobago resource path
   */
  @TagAttribute(required = true)
  @UIComponentTagAttribute()
  void setValue(String value);

  /**
   * Alternate textual description of the image rendered by this component.
   */
  @TagAttribute
  @UIComponentTagAttribute()
  void setAlt(String alt);

}

==> myfaces-tobago-2.4.0-source-release.zip: tobago-2.4.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/ImageTagDeclaration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.taglib.component;

import org.apache.myfaces.tobago.apt.annotation.Tag;
import org.apache.myfaces.tobago.apt.annotation.TagAttribute;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;
import org.apache.myfaces.tobago.component.RendererTypes;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasBorder;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasCurrentMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasIdBindingAndRendered;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasMarkup;
import org.apache.myfaces.tobago.internal.taglib.declaration.HasTip;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsDisabled;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsGridLayoutComponentWithDimension;
import org.apache.myfaces.tobago.internal.taglib.declaration.IsGridLayoutContainer;

import javax.faces.component.UIGraphic;

/**
 * Renders an image.
 */
@Tag(name = "image")
@UIComponentTag(
    uiComponent = "org.apache.myfaces.tobago.component.UIImage",
    uiComponentBaseClass = "org.apache.myfaces.tobago.internal.component.AbstractUIImage",
    uiComponentFacesClass = "javax.faces.component.UIGraphic",
    componentFamily = UIGraphic.COMPONENT_FAMILY,
    rendererType = RendererTypes.IMAGE,
    allowedChildComponenents = "NONE")
public interface ImageTagDeclaration
    extends HasIdBindingAndRendered, HasBorder, HasTip, IsDisabled, HasMarkup, HasCurrentMarkup,
    IsGridLayoutComponentWithDimension, IsGridLayoutContainer {

  /**
   * Absolute url to an image or image name to lookup in tobago resource path.
   * In the second case, there is no need to set the extension (like .gif or .png).
   * If you leave it out, you can use different extension in different themes.
   */
  @TagAttribute(required = true)
  @UIComponentTagAttribute()
  void setValue(String value);

  /**
   * Alternate textual description of the image rendered by this component.
   */
  @TagAttribute
  @UIComponentTagAttribute()
  void setAlt(String alt);

}
